@@ -286,9 +286,10 @@ class BaseRfcWriter:
 
     # -------------------------------------------------------------------------
 
-    def __init__(self, xmlrfc, quiet=False, verbose=False):
+    def __init__(self, xmlrfc, quiet=False, verbose=False, date=datetime.date.today()):
         self.quiet = quiet
         self.verbose = verbose
+        self.date = date
         self.expire_string = ''
         self.ascii = False
 
@@ -399,14 +400,14 @@ class BaseRfcWriter:
     
     def _format_date(self):
         """ Fix the date data """
-        today = datetime.date.today()
+        today = self.date
         date = self.r.find('front/date')
         if date is not None:
             year = date.attrib.get('year', '')
             month = date.attrib.get('month', '')
             # If year is this year, and month not specified, use current date
             if not year or (year == str(today.year) and not month) or \
-                           (year == str(today.year) and month == str(today.month)):
+                           (year == str(today.year) and month == today.strftime("%B")):
                 # Set everything to today
                 date.attrib['year'] = today.strftime('%Y')
                 date.attrib['month'] = today.strftime('%B')
@@ -423,7 +424,7 @@ class BaseRfcWriter:
                     try:
                         start_date = datetime.datetime.strptime(year + month + day, \
                                                                 '%Y%B%d')
-                        expire_date = start_date + datetime.timedelta(183)
+                        expire_date = start_date + datetime.timedelta(185)
                         self.expire_string = expire_date.strftime('%B %d, %Y')
                     except ValueError:
                         pass
@@ -446,6 +447,34 @@ class BaseRfcWriter:
             .replace(r'%i', xml2rfc.utils.int2roman(count)) \
             .replace(r'%I', xml2rfc.utils.int2roman(count, uppercase=True))
 
+    def _format_author_string(self, authors):
+        """ Given a list of <author> elements, return a readable string of names """
+        buf = []
+        for i, author in enumerate(authors):
+            organization = author.find('organization')
+            surname = author.attrib.get('surname', '')
+            if surname:
+                initials = author.attrib.get('initials', '')
+                # Append a dot if it doesnt already exist
+                if initials and not initials.endswith('.'):
+                    initials = initials + '.'
+                if i == len(authors) - 1 and len(authors) > 1:
+                    # Last author is rendered in reverse
+                    buf.append('and ' + initials + ' ' + \
+                                     surname)
+                else:
+                    buf.append(surname + ', ' + initials)
+                if author.attrib.get('role', '') == 'editor':
+                    buf.append(', Ed.')
+            elif organization is not None and organization.text:
+                # Use organization instead of name
+                buf.append(organization.text)
+            if len(authors) == 2 and i == 0:
+                buf.append(' ')
+            elif i < len(authors) - 1:
+                buf.append(', ')
+        return ''.join(buf)
+
     def _prepare_top_left(self):
         """ Returns a lines of lines for the top left header """
         lines = []
@@ -566,8 +595,8 @@ class BaseRfcWriter:
         
         if anchor:
             # Insert anchor(s) for the figure
-            self.insert_anchor('#rfc.figure.' + str(self.figure_count))
-            self.insert_anchor('#' + anchor)
+            self.insert_anchor('rfc.figure.' + str(self.figure_count))
+            self.insert_anchor(anchor)
             if self.indexmode:
                 # Add figure to the index, inserting any anchors necessary
                 self._indexFigure(self.figure_count, anchor=anchor, title=title)
@@ -612,8 +641,8 @@ class BaseRfcWriter:
 
         if anchor:
             # Insert anchor(s) for the table
-            self.insert_anchor('#rfc.table.' + str(self.table_count))
-            self.insert_anchor('#' + anchor)
+            self.insert_anchor('rfc.table.' + str(self.table_count))
+            self.insert_anchor(anchor)
             if self.indexmode:
                 # Add table to the index, inserting any anchors necessary
                 self._indexTable(self.table_count, anchor=anchor, title=title)
@@ -641,6 +670,7 @@ class BaseRfcWriter:
     
     def _index_t_rec(self, element):
         """ Traverse a <t> element only performing indexing operations """
+        pass
         
 
     def _write_section_rec(self, section, count_str, appendix=False, \
