@@ -8,6 +8,8 @@ import lxml
 import os.path
 import string
 import sys
+import datetime
+import cgi
 
 # Local libs
 import xml2rfc
@@ -24,8 +26,8 @@ class HtmlRfcWriter(BaseRfcWriter):
         'references_url': 'http://tools.ietf.org/html/',
     }
 
-    def __init__(self, xmlrfc, quiet=False, verbose=False, templates_dir=None):
-        BaseRfcWriter.__init__(self, xmlrfc, quiet=quiet, verbose=verbose)
+    def __init__(self, xmlrfc, quiet=False, verbose=False, date=datetime.date.today(), templates_dir=None):
+        BaseRfcWriter.__init__(self, xmlrfc, quiet=quiet, date=date, verbose=verbose)
         self.list_counters = {}
         self.iref_index = []
         
@@ -136,7 +138,7 @@ class HtmlRfcWriter(BaseRfcWriter):
             self.buffers['toc_rows'].append(self._serialize(li))
 
     def _serialize(self, element):
-        return lxml.html.tostring(element, pretty_print=True)
+        return lxml.html.tostring(element, pretty_print=True, method='xml')
     
     def _flush_temp_div(self):
         lines = []
@@ -498,11 +500,12 @@ class HtmlRfcWriter(BaseRfcWriter):
                 title_a.tail += seriesInfo.attrib.get('name', '') + ' ' + \
                              seriesInfo.attrib.get('value', '') + ', '
             date = reference.find('front/date')
-            month = date.attrib.get('month', '')
-            if month:
-                month += ' '
-            year = date.attrib.get('year', '')
-            title_a.tail += month + year + '.'
+            if date is not None:
+                month = date.attrib.get('month', '')
+                if month:
+                    month += ' '
+                year = date.attrib.get('year', '')
+                title_a.tail += month + year + '.'
             tr.append(bullet_td)
             tr.append(ref_td)
             tbody.append(tr)
@@ -635,15 +638,39 @@ class HtmlRfcWriter(BaseRfcWriter):
             description = abs_t.text
         keywords = self.r.findall('front/keyword')
         keyword_list = [keyword.text for keyword in keywords if keyword.text]
-        
+        generator = "xml2rfc version %s - http://tools.ietf.org/tools/xml2rfc" % \
+                    '.'.join(map(str, xml2rfc.VERSION))
+
+        # Build ISO8601 date string
+        docDate = ''
+        date = self.r.find('front/date')
+        if date is not None:
+            # We can assume AT LEAST year was defined in base.py from _format_date()
+            docDate = date.attrib.get('year', '')
+            try:
+                month = datetime.datetime.strptime(date.attrib.get('month', ''), '%B').month
+                docDate += "-%s" % month
+            except ValueError:
+                pass
+            if date.attrib.get('day'):
+                docDate += "-%s" % date.attrib.get('day')
+
+        # Build author string
+        authors = self._format_author_string(self.r.findall('front/author'))
+
         # Run through base template, store in main output string
         subs = { 
                  # Replace flat values 
                  'background':      background_image,
-                 'title':           title,
-                 'docName':         docName,
-                 'description':     description,
-                 'keywords':        ', '.join(keyword_list),
+
+                 # HTML-escaped values
+                 'docName':         cgi.escape(docName, quote=True),
+                 'docDate':         cgi.escape(docDate, quote=True),
+                 'description':     cgi.escape(description, quote=True),
+                 'generator':       cgi.escape(generator, quote=True),
+                 'authors':         cgi.escape(authors, quote=True),
+                 'keywords':        cgi.escape(', '.join(keyword_list), quote=True),
+                 'title':           cgi.escape(title),
                  
                  # Replace buffers
                  'front':           ''.join(self.buffers['front']),
