@@ -8,6 +8,7 @@ import textwrap
 import string
 import math
 import lxml
+import datetime
 
 # Local lib
 from xml2rfc.writers.base import BaseRfcWriter
@@ -20,8 +21,8 @@ class RawTextRfcWriter(BaseRfcWriter):
         The page width is controlled by the *width* parameter.
     """
 
-    def __init__(self, xmlrfc, width=72, quiet=False, verbose=False):
-        BaseRfcWriter.__init__(self, xmlrfc, quiet=quiet, verbose=verbose)
+    def __init__(self, xmlrfc, width=72, quiet=False, verbose=False, date=datetime.date.today()):
+        BaseRfcWriter.__init__(self, xmlrfc, quiet=quiet, verbose=verbose, date=date)
         # Document processing data
         self.width = width      # Page width
         self.buf = []           # Main buffer during processing
@@ -584,29 +585,8 @@ class RawTextRfcWriter(BaseRfcWriter):
         for i, ref in enumerate(list.findall('reference')):
             refstring = []
             authors = ref.findall('front/author')
-            for j, author in enumerate(authors):
-                organization = author.find('organization')
-                surname = author.attrib.get('surname', '')
-                if surname:
-                    initials = author.attrib.get('initials', '')
-                    # Append a dot if it doesnt already exist
-                    if initials and not initials.endswith('.'):
-                        initials = initials + '.'
-                    if j == len(authors) - 1 and len(authors) > 1:
-                        # Last author is rendered in reverse
-                        refstring.append('and ' + initials + ' ' + \
-                                         surname)
-                    else:
-                        refstring.append(surname + ', ' + initials)
-                    if author.attrib.get('role', '') == 'editor':
-                        refstring.append(', Ed.')
-                    if len(authors) == 2 and j == 0:
-                        refstring.append(' ')
-                    else:
-                        refstring.append(', ')
-                elif organization is not None and organization.text:
-                    # Use organization instead of name
-                    refstring.append(organization.text + ', ')
+            refstring.append(self._format_author_string(authors))
+            refstring.append(', ')
             title = ref.find('front/title')
             if title is not None and title.text:
                 refstring.append('"' + title.text + '", ')
@@ -614,8 +594,11 @@ class RawTextRfcWriter(BaseRfcWriter):
                 xml2rfc.log.warn('No title specified in reference', \
                                  ref.attrib.get('anchor', ''))
             for seriesInfo in ref.findall('seriesInfo'):
-                refstring.append(seriesInfo.attrib['name'] + ' ' + \
-                                 seriesInfo.attrib['value'] + ', ')
+                if seriesInfo.attrib['name'] == "Internet-Draft":
+                    refstring.append(seriesInfo.attrib['value'] + ' (work in progress), ')
+                else:
+                    refstring.append(seriesInfo.attrib['name'] + ' ' + \
+                                     seriesInfo.attrib['value'] + ', ')
             date = ref.find('front/date')
             if date is not None:
                 month = date.attrib.get('month', '')
